# StageBloc API Cocoa Framework

## Introduction

This framework is meant to be easily dropped into an Xcode project for seamless integration with the [StageBloc API](https://github.com/stagebloc/api).

The instructions below are meant to help you add this framework to an existing project. If you need help, a [demo project](https://github.com/stagebloc/stagebloc-cocoa-framework-demo) that uses Xcode Workspaces exists that you can play with.

## Getting Started

To be able to test your application, you'll first need to [sign up for a StageBloc account](http://www.stagebloc.com/signup). If you've already done that, you'll need to [register your application](http://stagebloc.com/account/admin/management/developers/) and receive a client ID and secret.

### Building / Contributing To The Framework

If you're interested in building the framework and contributing to it, there are a few simple steps to get going:

1. Clone this git repository to your local machine.

2. Add the required [OAuth2Client](https://github.com/nxtbgthng/OAuth2Client/) dependency by running the following commands from within the repository:

		git submodule init
		git submodule update

3. That's it, you're now ready to add to and build the framework. If you'd like to contribute, simply fork the repo and send in pull requests!

### Adding The Framework To Your Project

In order to use this framework with your application, you'll need to complete a few steps outlined below (also check out the [demo project](https://github.com/stagebloc/stagebloc-cocoa-framework-demo)):
 
1. Go to the repository directory in the command line and run the following commands:

        git submodule add git@github.com:stagebloc/cocoa-stagebloc-api.git
        git submodule add git://github.com/nxtbgthng/OAuth2Client.git        
    
    This will add git submodules for [StageBloc API Cocoa Framework](http://github.com/stagebloc/cocoa-stagebloc-api) and [nxbgthng's OAuth2Client](https://github.com/nxtbgthng/OAuth2Client/) (needed for the StageBloc API Framework) to your project.

2. Open and build each of those projects in Xcode such that their respective `/build` folders are created and filled.

3. Click your project in the top of the _Project Navigator_ and go to the _Build Phases_ tab for your target. In the _Link Binaries With Libraries_ section, add the `libOAuth2Client.a` and `libStageBlocAPI.a` files that were generated in step two. You'll also need `Security.framework`.

4. Add `-all_load -ObjC` to your project's _Other Linker Flags_ and `../**` to your target's _Header Search Paths_ in their respective _Build Settings_ tab.

5. Also be sure to add `StageBloc.bundle` to your project.

**JSON Note:** If you plan on using JSON for the response format, you'll also want to do the following steps.

1. Add a submodule for [nxbgthng's JSONKit](https://github.com/nxtbgthng/JSONKit).

        git submodule add git://github.com/nxtbgthng/JSONKit.git
        
2. Add libJSONKit.a to your projects _Link Binaries With Libraries_ (just like step three above).

### Using The Framework

1. Simply `#import <StageBlocAPI/StageBloc.h>` or `#import "StageBloc.h"` anywhere you want to use the framework.

2. Set your client ID and secret using the follow method of the `SBStageBloc` class (If you don't have these yet, see the _Getting Started_ section).

        + (void)setClientID:(NSString *)aClientID
                     secret:(NSString *)aSecret
                redirectURL:(NSURL *)aRedirectURL;
                
    Note: It's sometimes best to do this in the `+ (void)initialize` method of your project's delegate.
    
### Using The API

1. Documentation for the API can be found on StageBloc's [developer's page](http://stagebloc.com/developers/api/).

## Feedback And Questions

Found a bug or missing a feature? Don't hesitate to create a new issue here on GitHub.
